require 'rails/engine'

module DbCharmerEnvUrls
  class Engine < ::Rails::Engine
    # Merges any database urls from the ENV into the current environment's configurations
    #
    # @see https://github.com/rails/rails/blob/38af3540ae53b9f2fbdb649a68cde3edf182fe67/activerecord/lib/active_record/railtie.rb#L79 ActiveRecord's default initializer
    # @see DbCharmerEnvUrls.database_configurations
    initializer "db_charmer_env_urls.initialize_database", after: "active_record.initialize_database" do
      ActiveSupport.on_load(:active_record) do
        base = ActiveRecord::Base
        # This will not be set if DATABASE_URL isn't used
        base.configurations[Rails.env] ||= {}
        base.configurations[Rails.env].merge!(DbCharmerEnvUrls.database_configurations)
      end
    end

    rake_tasks do
      load 'tasks/db_charmer_env_urls.rake'
    end
  end
end
